﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace IpPbx.Client.Devices.Audio.Plugins.Sample
{
    /// <summary>
    /// This event is fired by UI when user wants to hook off/hook on.
    /// </summary>
    /// <param name="hookOff">True if hook off, false if hook on.</param>
    public delegate void OnHookHandler(bool hookOff);

    /// <summary>
    /// This event is fired by UI when user wants to mute/unmute the device.
    /// </summary>
    /// <param name="muted">True if device is muted, false if device is unmuted.</param>
    public delegate void OnMuteHandler(bool muted);

    /// <summary>
    /// This event is fired when UI wants to reject a call.
    /// </summary>
    public delegate void OnRejectCallHandler();

    /// <summary>
    /// This is a small interface to support abstract UI interaction.
    /// </summary>
    public interface IAudioDeviceSampleGUI
    {
        event OnHookHandler OnHook;
        event OnMuteHandler OnMute;
        event OnRejectCallHandler OnRejectCall;

        string AudioDeviceName
        {
            get;
            set;
        }

        void ShowWindow();
        void CloseWindow();
        void SetHookedOff(bool hookedOff);
        void SetMuted(bool muted);
        void SetCallerText(string caller);
        void SetRinger(bool ringing);
    }
}
