﻿using System;
using System.Windows.Forms;
using System.Drawing;

namespace IpPbx.Client.Devices.Audio.Plugins.Sample.UI.WinForms
{
    /// <summary>
    /// A simple Windows.Forms dialog implementation to allow user
    /// sending hook and mute events to Client Line Manager.
    /// </summary>
    public partial class frmDemoUI : Form, IAudioDeviceSampleGUI
    {
        #region fields

        private bool currUiHookState = false;
        private bool currUiMutedState = false;

        #endregion

        #region delegates

        private delegate void SetBoolHandler(bool b);
        private delegate void SetStringHandler(string val);

        #endregion

        #region constructor

        public frmDemoUI()
        {
            InitializeComponent();
        }

        #endregion

        #region IAudioDeviceSampleGUI Members

        public event OnHookHandler OnHook;

        public event OnMuteHandler OnMute;

        public event OnRejectCallHandler OnRejectCall;

        public string AudioDeviceName
        {
            get
            {
                return this.Text;
            }
            set
            {
                this.Text = value;
            }
        }

        public void ShowWindow()
        {
            this.ShowDialog();
        }

        private delegate void CloseWindowDel();
        public void CloseWindow()
        {
            if (InvokeRequired)
            {
                BeginInvoke(
                    new CloseWindowDel(CloseWindow));
            }
            else
            {
                Close();
            }
        }

        #endregion

        #region private methods

        private void btnMute_Click(object sender, EventArgs e)
        {
            // Switch
            SetUIMute(!this.currUiMutedState);
        }

        private void SetUIMute(bool muted)
        {
            this.currUiMutedState = muted;
            btnMute.Text = this.currUiMutedState ? "Unmute" : "Mute";
            Image img;
            if (!this.currUiMutedState)
                img = IpPbx.Client.Devices.Audio.Plugins.Sample.Properties.Resources.Microphone1_32;
            else
                img = IpPbx.Client.Devices.Audio.Plugins.Sample.Properties.Resources.Microphone1_Cancel_32;
            btnMute.Image = img;
            if (OnMute != null)
                OnMute(this.currUiMutedState);
        }

        private void btnHook_Click(object sender, EventArgs e)
        {
            // Switch
            SetUIHook(!this.currUiHookState);
        }


        private void SetUIHook(bool hookOff)
        {
            this.currUiHookState = hookOff;
            btnHook.Text = this.currUiHookState ? "Hook On" : "Hook Off";
            Image img;
            if (!this.currUiHookState)
                img = IpPbx.Client.Devices.Audio.Plugins.Sample.Properties.Resources.Old_Phone_32;
            else
                img = IpPbx.Client.Devices.Audio.Plugins.Sample.Properties.Resources.Old_Phone_32_hookoff;
            btnHook.Image = img;
            if (OnHook != null)
                OnHook(this.currUiHookState);
        }

        #endregion

        #region public methods

        public void SetHookedOff(bool hookedOff)
        {
            if(InvokeRequired)
            {
                BeginInvoke(new SetBoolHandler(SetHookedOff), hookedOff);
            }
            else
            {
                SetUIHook(hookedOff);
            }
        }

        public void SetMuted(bool muted)
        {
            if(InvokeRequired)
            {
                BeginInvoke(new SetBoolHandler(SetMuted), muted);
            }
            else
            {
                SetUIMute(muted);
            }
        }

        public void SetCallerText(string caller)
        {
            if (InvokeRequired)
            {
                BeginInvoke(new SetStringHandler(SetCallerText), caller);
            }
            else
            {
                txtCallerInfo.Text = caller;
            }
        }

        public void SetRinger(bool ringing)
        {
            if (InvokeRequired)
            {
                BeginInvoke(new SetBoolHandler(SetRinger), ringing);
            }
            else
            {
                btnReject.Enabled = ringing;
                ringingTimer.Enabled = ringing;
                if (!ringing)
                {
                    txtCallerInfo.BackColor = SystemColors.InactiveBorder;
                    txtCallerInfo.ForeColor = SystemColors.WindowText;
                }
            }
        }

        #endregion

        #region event handlers

        private void btnReject_Click(object sender, EventArgs e)
        {
            if (OnRejectCall != null)
                OnRejectCall();
        }

        private void ringingTimer_Tick(object sender, EventArgs e)
        {
            if (txtCallerInfo.BackColor.Equals(Color.Green))
            {
                txtCallerInfo.BackColor = SystemColors.InactiveBorder;
                txtCallerInfo.ForeColor = SystemColors.WindowText;
            }
            else
            {
                txtCallerInfo.BackColor = Color.Green;
                txtCallerInfo.ForeColor = Color.White;
            }
        }

        #endregion
    }
}
